==> GeneSpring_1.0.1.tar.gz: GeneSpring/man/GSsave.exp.Rd <==
\name{GSsave.exp}
\alias{GSsave.exp}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Save a GeneSpring Interpretation to file}
\description{
The normalized values of the GeneSpring Interpretation object will be written to file.
If the Interpretation object contains Control values, they will also be used.
The experimental paramters and the experiment name will also be inlucded.
}
\usage{
GSsave.exp(interpretation, filename = "GS_R_out.txt")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{interpretation}{ The GeneSpring Experiment Interpretation object of class \code{GSint}}
  \item{filename}{ Name of the file. Can also be a connection object.}
}
\details{
A GeneSpring Experiment consists of the Normalized expression values for each sample
and optionally the Control values for that normalized value. Each sample or hybridization
has its own column (set) of expression values, wheras the expression values for
an Experiment INTERPRETATION represent the mean value of the replicate values for that
condition.

For more information see the manual entry for \code{\link{GSload.exp}}.
}
\value{
This function does not return a usable value upon return.
}
\references{

For more information on using GeneSpring with R see
\url{http://www.silicongenetics.com/cgi/SiG.cgi/Support/GeneSpring/GSnotes/R.smf}
}

\author{

   Thon de Boer, Silicon Genetics, Redwood city, CA, USA \email{thon@silicongenetics.com}

}

\note{
This and any other functions in the GeneSpring package are only useful,
when using Silicon Genetics Gene Expression software GeneSpring.
}

\seealso{
\code{\link{GSload.exp}},
\code{\link{GSload.int}}

}
\examples{

#Use the example data etc. from exprSet
library(Biobase)
data(geneData)
data(geneCov)
covdesc<- list("Covariate 1", "Covariate 2", "Covariate 3")
names(covdesc) <- names(geneCov)
pdata <- new("phenoData", pData=geneCov, varLabels=covdesc)
eset <- new("exprSet", exprs=geneData, phenoData=pdata)

#Convert the objects into GeneSpring objects
gs.int <- BC2GSint(eset)

#Save the Experiment in GeneSpring format
GSsave.exp(gs.int, filename = "GS_R_out.txt")

}
\keyword{ IO }

==> GeneSpring_2.4.0.tar.gz: GeneSpring/man/GSsave.exp.Rd <==
\name{GSsave.exp}
\alias{GSsave.exp}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Save a GeneSpring Interpretation to file}
\description{
The normalized values of the GeneSpring Interpretation object will be written to file.
If the Interpretation object contains Control values, they will also be used.
The experimental paramters and the experiment name will also be inlucded.
}
\usage{
GSsave.exp(interpretation, filename = "GS_R_out.txt")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{interpretation}{ The GeneSpring Experiment Interpretation object of class \code{GSint}}
  \item{filename}{ Name of the file. Can also be a connection object.}
}
\details{
A GeneSpring Experiment consists of the Normalized expression values for each sample
and optionally the Control values for that normalized value. Each sample or hybridization
has its own column (set) of expression values, wheras the expression values for
an Experiment INTERPRETATION represent the mean value of the replicate values for that
condition.

For more information see the manual entry for \code{\link{GSload.exp}}.
}
\value{
This function does not return a usable value upon return.
}
\references{

For more information on using GeneSpring with R see
\url{http://www.chem.agilent.com/scripts/generic.asp?lpage=34733}
}

\author{

   Thon de Boer, Agilent Technologies, Santa Clara, CA, USA \email{thon\_deboer@agilent.com}
}

\note{
This and any other functions in the GeneSpring package are only useful,
when using Agilent Technologies Gene Expression software GeneSpring.
}

\seealso{
\code{\link{GSload.exp}},
\code{\link{GSload.int}}

}
\examples{

#Use the example data etc. from exprSet
library(Biobase)
data(geneData)
data(geneCov)
covdesc<- list("Covariate 1", "Covariate 2", "Covariate 3")
names(covdesc) <- names(geneCov)
pdata <- new("phenoData", pData=geneCov, varLabels=covdesc)
eset <- new("exprSet", exprs=geneData, phenoData=pdata)

#Convert the objects into GeneSpring objects
gs.int <- BC2GSint(eset)

#Save the Experiment in GeneSpring format
GSsave.exp(gs.int, filename = "GS_R_out.txt")

}
\keyword{ IO }
